using System.Text.Json;
using System.Text.RegularExpressions;
using HermesSocketLibrary.Requests.Messages;
using Serilog;

namespace TwitchChatTTS.Hermes.Socket.Requests
{
    public class GetTTSWordFiltersAck : IRequestAck
    {
        public string Name => "get_tts_word_filters";
        private readonly User _user;
        private readonly JsonSerializerOptions _options;
        private readonly ILogger _logger;

        public GetTTSWordFiltersAck(User user, JsonSerializerOptions options, ILogger logger)
        {
            _user = user;
            _options = options;
            _logger = logger;
        }

        public void Acknowledge(string requestId, string? json, IDictionary<string, object>? requestData)
        {
            var wordFilters = JsonSerializer.Deserialize<IEnumerable<TTSWordFilter>>(json, _options);
            if (wordFilters == null)
            {
                _logger.Error("Failed to load word filters.");
                return;
            }

            var filters = wordFilters.Where(f => f.Search != null && f.Replace != null).ToList();
            foreach (var filter in filters)
            {
                try
                {
                    var re = new Regex(filter.Search, ((RegexOptions) filter.Flag) | RegexOptions.Compiled);
                    re.Match(string.Empty);
                    filter.Regex = re;
                }
                catch (Exception) { }
            }
            _user.RegexFilters = filters;
            _logger.Information($"TTS word filters [count: {_user.RegexFilters.Count}] have been refreshed.");
        }
    }
}